{% extends "core/base.html" %}

{% load i18n %}

{% block content %}

  {% if not error %}
    <div class="container">
      <div class="card green">
        <div class="card-content white-text">
          <div class="material-icons small left">check</div>
          <span class="card-title">{% blocktrans %}Success!{% endblocktrans %}</span>
          <p>
            {% trans "Please return to your application and enter this code:" %} {{ code }}
          </p>
        </div>
      </div>
    </div>
  {% else %}
    <div class="container">
      <div class="card red">
        <div class="card-content white-text">
          <div class="material-icons small left">error_outline</div>
          <span class="card-title">{% trans "Error" %}: {{ error.error }}</span>
          <p>
            {{ error.description }}
          </p>
          <p>
            Please verify if the application is configured correctly or contact one of your site administrators:
          </p>
          {% include "core/partials/admins_list.html" %}
        </div>
      </div>
    </div>
  {% endif %}
{% endblock %}
