body {
    line-height: 1.5;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-weight: normal;
    color: rgba(0, 0, 0, 0.87);
}

.count {
    text-align: right;
    font-family: monospace;
    font-size: 14pt;
}

td, th {
    padding: 10px;
}
