{% extends "core/base.html" %}

{% load i18n %}

{% block browser_title %}{% blocktrans %}OAuth2 Applications{% endblocktrans %}{% endblock %}

{% block content %}
  <h1>{% blocktrans %}OAuth2 applications{% endblocktrans %}</h1>
  <a href="{% url "oauth2_provider:register" %}" class="btn green waves-effect
  waves-light">
    <i class="material-icons left">add</i>
    {% blocktrans %}Register new applications{% endblocktrans %}
  </a>
  <ul class="collection">
  {% for application in applications %}
      <li class="collection-item">
        <div>
          <a href="{% url "oauth_detail" application.id %}">{{ application.name }}</a>
        </div>
      </li>
  {% empty %}
      <li class="collection-item flow-text">
        {% blocktrans %}No applications defined.{% endblocktrans %}
      </li>
  {% endfor %}
  </ul>
{% endblock %}
