{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% blocktrans %}Create OAuth2 Application{% endblocktrans %}{% endblock %}

{% block content %}
  <h4 class="block-center-heading">
    {% block app-form-title %}
      {% blocktrans with application_name=application.name %}Edit application{% endblocktrans %}
    {% endblock app-form-title %}
  </h4>
  <form method="post">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% include "core/partials/save_button.html" %}
    <a class="btn waves-effect red waves-light" href="{% block app-form-back-url %}{% url "oauth_detail" application.id %}{% endblock app-form-back-url %}">
      <i class="material-icons left">clear</i> {% trans "Cancel"%}
    </a>
  </form>
{% endblock %}
