{% load i18n %}

{% if cancel_url %}
  <a href="{{ cancel_url }}" class="btn red waves-effect waves-light">
    <i class="material-icons left">cancel</i>
    {% trans "Cancel" %}
  </a>
{% endif %}

{% if wizard.steps.prev %}
  <button name="wizard_goto_step" type="submit"
          value="{{ wizard.steps.prev }}"
          class="btn grey waves-effect waves-light">
    <i class="material-icons left">arrow_back</i>
    {% trans "Back" %}
  </button>
{% else %}
  <button disabled name="" type="button" class="btn grey disabled">
    <i class="material-icons left">arrow_back</i>
    {% trans "Back" %}
  </button>
{% endif %}

<button type="submit" class="btn green waves-effect waves-light">
  <i class="material-icons right">arrow_forward</i>
  {% trans "Next" %}
</button>
