{% load i18n %}

<div class="card horizontal">
  <div class="card-image">
    <i class="material-icons large red-text stacked-card-icon">assignment_late</i>
  </div>
  <div class="card-stacked">
    <div class="card-content">
      <div class="card-title">
        {% trans "This widget is currently not available." %}
      </div>
      {% if title %}
        <p>
          {% blocktrans %}
            There is a problem getting the widget "{{ title }}".
            There is no need for you to take any action.
          {% endblocktrans %}
        </p>
      {% endif %}
    </div>
  </div>
</div>
