{% load i18n socialaccount %}
<p>
  {% get_providers as socialaccount_providers %}
  {% if socialaccount_providers %}
    {% for provider in socialaccount_providers %}
      {% if provider.id == "openid" %}
        {% for brand in provider.get_brands %}
            <a title="{{brand.name}}" 
              class="socialaccount_provider {{provider.id}} {{brand.id}}
              btn-large waves-effect waves-light primary-color" 
              href="{% provider_login_url provider.id openid=brand.openid_url process=process %}">
              {% blocktrans with name=brand.name %}
                Login with {{ name }}
              {% endblocktrans %}
            </a>
        {% endfor %}
      {% endif %}
        <a title="{{provider.name}}" class="socialaccount_provider {{provider.id}}
        btn hundred-percent waves-effect waves-light primary-color" 
          href="{% provider_login_url provider.id process=process scope=scope auth_params=auth_params %}">
          {% blocktrans with name=provider.name %}
            Login with {{ name }}
          {% endblocktrans %}
        </a>
    {% endfor %}
  {% else %}
    <div class="alert primary">
      <div>
        <i class="material-icons left">info</i>
        {% blocktrans %}
          No third-party account providers available.
        {% endblocktrans %}
      </div>
    </div>
  {% endif %}
</p>
