{% extends "core/base.html" %}
{% load data_helpers i18n %}

{% block browser_title %}
  {% verbose_name_object object as object_name %}
  {% blocktrans with object_name=object_name %}Delete {{ object_name }}{% endblocktrans %}
{% endblock %}

{% block content %}
  {% verbose_name_object object as object_name %}

  <p class="flow-text">
    {% blocktrans with object_name=object_name object=object %}
      Do you really want to delete the {{ object_name }} "{{ object }}"?
    {% endblocktrans %}
  </p>

  <form method="post" action="">
    {% csrf_token %}
    <button type="submit" class="btn red waves-effect waves-light">
      <i class="material-icons left">delete</i>
      {% trans "Delete" %}
    </button>
  </form>
{% endblock %}
