{% extends "core/base.html" %}

{% load i18n %}

{% block browser_title %}{% trans "Reset password" %}{% endblock %}
{% block no_page_title %}{% endblock %}

{% block content %}

  <div class="container">
    <div class="card green">
      <div class="card-content white-text">
        <div class="card-title">
          <i class="material-icons small left">check_circle</i>
          {% blocktrans %}Password reset mail sent{% endblocktrans %}
        </div>
        <p>
          {% blocktrans %}
            We have sent you an e-mail. Please contact one of your site
            administrators if you do not receive it within a few minutes.
          {% endblocktrans %}
        </p>
        {% include "core/partials/admins_list.html" %}
      </div>
    </div>
  </div>

{% endblock %}
