{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% trans "Change password" %}{% endblock %}
{% block page_title %}{% trans "Change password" %}{% endblock %}

{% block content %}
  <div class="alert warning">
    <p>
      <i class="material-icons left">warning</i>
      {% trans "Forgot your current password? Click here to reset it:" %} <a href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a>.
    </p>
  </div>

  <form method="post" action="{% url 'account_change_password' %}">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% trans "Change password" as caption %}
    {% include "core/partials/save_button.html" with caption=caption icon="priority_high" %}
  </form>

{% endblock %}
