<span class="text-collapsible opened">
    <span class="a">
      {% include template with item=qs.first %} –
      {% include template with item=qs.last %}
    </span>
    <i class="material-icons open-icon" title="Show more">add_circle_outline</i>
    <span class="b">
      {% for item in qs %}
        {% include template with item=item %}
      {% endfor %}
    </span>
    <i class="material-icons close-icon" title="Show less">remove_circle_outline</i>
</span>
