{# -*- engine:django -*- #}

<div class="row">
  <a href="{{ url_prev }}" class="btn-flat left">
    <i class="material-icons small">chevron_left</i>
  </a>
  <a href="{{ url_next }}" class="btn-flat right">
    <i class="material-icons small">chevron_right</i>
  </a>
</div>
