<div class="card">
        <div class="card-image">
                <img src="{{ icon_url }}" alt="{{ title }}" />
        </div>
        <div class="card-action">
                <a href="{{ url }}">{{ title }}</a>
        </div>
</div>
