{% extends "core/base.html" %}
{% load i18n %}


{% block content %}
  <div class="container">
    <div class="card red">
      <div class="card-content white-text">
        <i class="material-icons small left">error_outline</i>
        <span class="card-title">{% trans "Error" %} (404): {% blocktrans %}The requested page or object was not
          found.{% endblocktrans %}</span>
        <p>
          {% blocktrans %}
            If you were redirected by a link on an external page,
            it is possible that that link was outdated.
          {% endblocktrans %}
          {% blocktrans %}
            If you think this is an error in AlekSIS, please contact your site
            administrators:
          {% endblocktrans %}
        </p>
        {% include "core/partials/admins_list.html" %}
      </div>
    </div>
  </div>
{% endblock %}
