{% load i18n %}
<button type="submit" class="btn waves-effect waves-light green">
  {% trans "Save" as default %}
  <i class="material-icons left">{{ icon|default:"save" }}</i> {{ caption|default:default }}
</button>
