{% extends "two_factor/_base_focus.html" %}
{% load i18n material_form %}

{% block browser_title %}
  {% trans "Disable Two-Factor Authentication" %}
{% endblock %}

{% block content %}
  <h1>{% block title %}{% trans "Disable Two-Factor Authentication" %}{% endblock %}</h1>

  <p class="flow-text">
    {% blocktrans trimmed %}
      You are about to disable two-factor authentication. This
      weakens your account security, are you sure?
    {% endblocktrans %}
  </p>

  <form method="post">
    {% csrf_token %}
    <p>
      {% form form=form %}{% endform %}
    </p>

    <button class="btn red waves-effect waves-light" type="submit">
      <i class="material-icons left">power_settings_new</i>
      {% trans "Disable" %}
    </button>
  </form>
{% endblock %}
