<div class="collection">
  {% for person in persons %}
    <a class="collection-item" href="{% url "person_by_id" person.pk %}">
      <i class="material-icons left">person</i>
      {{ person }}
    </a>
  {% endfor %}
</div>
