# Generated by Django 3.1.4 on 2020-12-20 15:55

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0005_timestamped_activity_notification'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboardwidget',
            name='size_l',
            field=models.PositiveSmallIntegerField(default=6, help_text='> 992 px, 12 columns', validators=[django.core.validators.MaxValueValidator(12)], verbose_name='Size on desktop devices'),
        ),
        migrations.AddField(
            model_name='dashboardwidget',
            name='size_m',
            field=models.PositiveSmallIntegerField(default=12, help_text='> 600 px, 12 columns', validators=[django.core.validators.MaxValueValidator(12)], verbose_name='Size on tablet devices'),
        ),
        migrations.AddField(
            model_name='dashboardwidget',
            name='size_s',
            field=models.PositiveSmallIntegerField(default=12, help_text='<= 600 px, 12 columns', validators=[django.core.validators.MaxValueValidator(12)], verbose_name='Size on mobile devices'),
        ),
        migrations.AddField(
            model_name='dashboardwidget',
            name='size_xl',
            field=models.PositiveSmallIntegerField(default=4, help_text='> 1200 px>, 12 columns', validators=[django.core.validators.MaxValueValidator(12)], verbose_name='Size on large desktop devices'),
        ),
    ]
