{# -*- engine:django -*- #}
{% extends "core/base.html" %}
{% load i18n menu_generator %}


{% block browser_title %}{% blocktrans %}Data management{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Data management{% endblocktrans %}{% endblock %}

{% block content %}
  {% get_menu "DATA_MANAGEMENT_MENU" as menu %}
  {% include "core/partials/on_page_menu.html" %}
{% endblock %}
