{# -*- engine:django -*- #}

{% extends "core/base.html" %}
{% load material_form i18n data_helpers %}

{% block browser_title %}
  {% verbose_name_object model as widget_title %}
  {% blocktrans with widget=widget_title %}Create {{ widget }}{% endblocktrans %}
{% endblock %}
{% block page_title %}
  {% verbose_name_object model as widget_title %}
  {% blocktrans with widget=widget_title %}Create {{ widget }}{% endblocktrans %}
{% endblock %}

{% block content %}

  <form method="post">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% include "core/partials/save_button.html" %}
  </form>

{% endblock %}
