{% if form.non_field_errors %}
  <div class="alert error">
    {% for error in form.non_field_errors %}
      <div><i class="material-icons left">error</i> {{ error }}</div>
    {% endfor %}
  </div>
{% endif %}
